@@ -11,7 +11,7 @@ use Plift::Context;
 use Digest::MD5 qw/ md5_hex /;
 use namespace::clean;
 
-our $VERSION = "0.11";
+our $VERSION = "0.12";
 
 use constant {
     XML_DOCUMENT_NODE      => 9,
@@ -60,7 +60,7 @@ sub _after_load_template {
 
     # remove-if/unless
     my $xpath =  join ' | ', map { ("./*[\@$_]", ".//*[\@$_]") }
-                             map { "data-$_"  }
+                             map { ($_, "data-$_")  }
                              qw/ remove-if remove-unless /;
 
     foreach my $node ( @{ $dom->xfilter($xpath)->{nodes} }, @{ $dom->xfind($xpath)->{nodes} } ) {
