@@ -21,6 +21,7 @@ has 'inactive_handlers', is => 'rw';
 has 'internal_id_attribute', is => 'ro', default => 'data-plift-id';
 has '_load_template', is => 'ro', required => 1, init_arg => 'load_template';
 has '_load_snippet', is => 'ro', required => 1, init_arg => 'load_snippet';
+has '_run_hooks', is => 'ro', required => 1, init_arg => 'run_hooks';
 
 
 has 'document', is => 'rw', init_arg => undef;
@@ -225,6 +226,8 @@ sub get {
     my ($self, $reference) = @_;
 
     my $data = $self->data;
+    return $data if $reference eq '.';
+
     my @keys = split /\./, $reference;
 
     # empty key
@@ -305,7 +308,10 @@ sub process_template {
     local $self->{current_path} = $self->{current_path};
 
     my $element = $self->load_template($template_name);
+    $self->_run_hooks->('after_load_template', [$self, $element, $template_name]);
+    $self->_run_hooks->('before_process_template', [$self, $element, $template_name]);
     $self->process_element($element);
+    $self->_run_hooks->('after_process_template', [$self, $element, $template_name]);
 
     $element;
 }
@@ -411,7 +417,9 @@ sub render  {
 
     # rewind directive stack, then render
     $self->rewind_directive_stack;
+    $self->_run_hooks->('before_render_directives', [$self, $element]);
     $self->_render_directives($element, $self->directives->{directives});
+    $self->_run_hooks->('after_render_directives', [$self, $element]);
 
     # TODO output filters
 
@@ -437,7 +445,7 @@ sub _render_directives {
         my ($selector, $attribute) = split '@', $match_spec;
         my $action = $directives->[$i+1];
 
-        my $target_element = $el->find($selector);
+        my $target_element = $selector eq '.' ? $el : $el->find($selector);
         $target_element = $el->filter($selector) if $target_element->size == 0;
         next unless $target_element->size > 0;
 
@@ -470,7 +478,7 @@ sub _render_directives {
                     unless $mod->{prepend} || $mod->{append};
 
                 $mod->{prepend} ? $target_element->prepend($value)
-                              : $target_element->append($value);
+                                : $target_element->append($value);
             }
         }
 
